<?php

namespace App\Entity;

use AllowDynamicProperties;
use App\Repository\ClientsRepository;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;

#[AllowDynamicProperties] #[ORM\Entity(repositoryClass: ClientsRepository::class)]
class Clients
{
    #[ORM\Id]
    #[ORM\GeneratedValue]
    #[ORM\Column]
    private ?int $id = null;

    #[ORM\Column(length: 255)]
    private ?string $Prenom = null;

    #[ORM\Column(length: 255)]
    private ?string $Nom = null;

    #[ORM\Column(length: 255)]
    private ?string $Email = null;

    #[ORM\Column(length: 255)]
    private ?string $Telephone = null;

    /**
     * @var Collection<int, Tables>
     */
    #[ORM\ManyToMany(targetEntity: Tables::class, mappedBy: 'Clients')]
    public Collection $tables;

    /**
     * @var Collection<int, Commandes>
     */
    #[ORM\ManyToMany(targetEntity: Commandes::class, mappedBy: 'Client')]
    private Collection $commandes;

    #[ORM\Column]
    private ?float $totalDepense = null;

    #[ORM\OneToMany(targetEntity: Reductions::class, mappedBy: 'client', cascade: ['persist', 'remove'])]
    private Collection $reductions;

    public function __construct()
    {
        $this->tables = new ArrayCollection();
        $this->commandes = new ArrayCollection();
        $this->reductions = new ArrayCollection();
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getPrenom(): ?string
    {
        return $this->Prenom;
    }

    public function setPrenom(string $Prenom): static
    {
        $this->Prenom = $Prenom;

        return $this;
    }

    public function getNom(): ?string
    {
        return $this->Nom;
    }

    public function setNom(string $Nom): static
    {
        $this->Nom = $Nom;

        return $this;
    }

    public function getEmail(): ?string
    {
        return $this->Email;
    }

    public function setEmail(string $Email): static
    {
        $this->Email = $Email;

        return $this;
    }

    public function getTelephone(): ?string
    {
        return $this->Telephone;
    }

    public function setTelephone(string $Telephone): static
    {
        $this->Telephone = $Telephone;

        return $this;
    }

    /**
     * @return Collection<int, Tables>
     */
    public function getTables(): Collection
    {
        return $this->tables;
    }

    public function addTable(Tables $tables): static
    {
        if (!$this->tables->contains($tables)) {
            $this->tables->add($tables);
        }

        return $this;
    }

    public function removeTable(Tables $tables): static
    {
        $this->tables->removeElement($tables);

        return $this;
    }

    /**
     * @return Collection<int, Commandes>
     */
    public function getCommandes(): Collection
    {
        return $this->commandes;
    }

    public function addCommande(Commandes $commande): static
    {
        if (!$this->commandes->contains($commande)) {
            $this->commandes->add($commande);
            $commande->addClient($this);
        }

        return $this;
    }

    public function removeCommande(Commandes $commande): static
    {
        if ($this->commandes->removeElement($commande)) {
            $commande->removeClient($this);
        }

        return $this;
    }


    public function getTotalDepense(): ?float
    {
        return $this->totalDepense;
    }

    public function setTotalDepense(float $totalDepense): static
    {
        $this->totalDepense = $totalDepense;

        return $this;
    }

    // Dans l'entité Clients
    public function appliquerReduction(): void
    {
        $montantTotal = $this->getTotalDepense();

        // Vérifie s'il y a des réductions valides disponibles
        $reductions = $this->getReductions(); // Récupérer toutes les réductions du client

        foreach ($reductions as $reduction) {
            // Vérifie si la réduction est valide (date de validité et montant minimum)
            if ($reduction->getDateDebut() <= new \DateTime() && $reduction->getDateFin() >= new \DateTime()) {
                if ($montantTotal >= $reduction->getMontantMin()) {
                    // Applique la réduction en pourcentage au total des dépenses
                    $reductionMontant = ($montantTotal * $reduction->getPourcentage()) / 100;
                    $nouveauTotal = $montantTotal - $reductionMontant; // Nouveau montant après réduction
                    $this->setTotalDepense($nouveauTotal); // Mise à jour du total des dépenses du client

                    // Met à jour l'objet client avec la réduction
                    break; // Si une réduction a été appliquée, on arrête
                }
            }
        }
    }

    public function getReductions(): Collection
    {
        return $this->reductions;
    }

    public function addReduction(Reductions $reduction): static
    {
        if (!$this->reductions->contains($reduction)) {
            $this->reductions->add($reduction);
        }
        return $this;
    }

    public function removeReduction(Reductions $reduction): static
    {
        $this->reductions->removeElement($reduction);
        return $this;
    }
}
